'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

var createShadowDOM = function (currentChild, pushShadowItem) {
    var children = currentChild.props.children;
    if (Array.isArray(children)) {
        React__default.Children.forEach(children, function (child) {
            if (typeof child === "object")
                createShadowDOM(child, pushShadowItem);
            else if (child.toString().trim().length) {
                setNewChild();
            }
        });
    }
    else if (typeof children === "object") {
        createShadowDOM(children, pushShadowItem);
    }
    else if (children.toString().trim().length) {
        setNewChild();
    }
    function setNewChild() {
        pushShadowItem(function (child) {
            if (child)
                return __spreadArrays(child, [currentChild]);
            return [currentChild];
        });
    }
};

var setHighlight = function (ref, isInitial, hideAfter) {
    if (!isInitial && ref.current) {
        var element_1 = ref.current.style;
        element_1.background = "#f8ffb4";
        setTimeout(function () {
            element_1.background = "#fff";
        }, hideAfter);
    }
};

var ShadowChild = function (props) {
    var initialMount = React.useRef(true);
    var child = props.child, _a = props.hideAfter, hideAfter = _a === void 0 ? 2000 : _a;
    var childrenToWatch = Array.isArray(child.props.children)
        ? child.props.children.find(function (c) { return c.toString().trim().length; })
        : child.props.children;
    React.useEffect(function () {
        if (initialMount.current) {
            initialMount.current = false;
            return;
        }
        setHighlight(child.ref, initialMount.current, hideAfter);
    }, [childrenToWatch]);
    return React__default.createElement(React__default.Fragment, null);
};

var ChangeHighlight = function (_a) {
    var children = _a.children, hideAfter = _a.hideAfter;
    var _b = React.useState([]), shadowDOM = _b[0], setShadowDOM = _b[1];
    var isInitialMount = React.useRef(true);
    React.useEffect(function () {
        if (isInitialMount.current) {
            isInitialMount.current = false;
        }
        setShadowDOM([]);
        createShadowDOM({ props: { children: children } }, setShadowDOM);
    }, [children]);
    return (React__default.createElement(React__default.Fragment, null,
        shadowDOM.map(function (child, index) { return (React__default.createElement(ShadowChild, { key: index, child: child, hideAfter: hideAfter })); }),
        children));
};

module.exports = ChangeHighlight;
